---
title: <span class="badge object-type-scalar"></span> DateTimeFromNow
---
# <span class="badge object-type-scalar"></span> DateTimeFromNow

Date & time: From Now

## Definition

```python
# Date & time: From Now
DateTimeFromNow: typing.Literal["dateTimeFromNow"] = "dateTimeFromNow"
```
